import { IChatModel, IConfig } from '@jupyter/chat';
import { IThemeManager } from '@jupyterlab/apputils';
import { ABCWidgetFactory, DocumentRegistry } from '@jupyterlab/docregistry';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { Contents } from '@jupyterlab/services';
import { Signal } from '@lumino/signaling';
import { CollaborativeChatModel } from './model';
import { CollaborativeChatWidget } from './widget';
import { YChat } from './ychat';
import { IWidgetConfig } from './token';
/**
 * The object provided by the chatDocument extension.
 * It is used to set the current config (from settings) to newly created chat widget,
 * and to propagate every changes to the existing chat widgets.
 */
export declare class WidgetConfig implements IWidgetConfig {
    /**
     * The constructor of the WidgetConfig.
     */
    constructor(config: Partial<IConfig>);
    config: Partial<IConfig>;
    configChanged: Signal<this, Partial<IConfig>>;
}
/**
 * A widget factory to create new instances of CollaborativeChatWidget.
 */
export declare class ChatWidgetFactory extends ABCWidgetFactory<CollaborativeChatWidget, CollaborativeChatModel> {
    /**
     * Constructor of ChatWidgetFactory.
     *
     * @param options Constructor options
     */
    constructor(options: ChatWidgetFactory.IOptions<CollaborativeChatWidget>);
    /**
     * Create a new widget given a context.
     *
     * @param context Contains the information of the file
     * @returns The widget
     */
    protected createNewWidget(context: ChatWidgetFactory.IContext): CollaborativeChatWidget;
    private _themeManager;
    private _rmRegistry;
}
export declare namespace ChatWidgetFactory {
    interface IContext extends DocumentRegistry.IContext<CollaborativeChatModel> {
        chatModel: IChatModel;
        themeManager: IThemeManager | null;
        rmRegistry: IRenderMimeRegistry;
    }
    interface IOptions<T extends CollaborativeChatWidget> extends DocumentRegistry.IWidgetFactoryOptions<T> {
        themeManager: IThemeManager | null;
        rmRegistry: IRenderMimeRegistry;
    }
}
export declare class CollaborativeChatModelFactory implements DocumentRegistry.IModelFactory<CollaborativeChatModel> {
    constructor(options: CollaborativeChatModel.IOptions);
    collaborative: boolean;
    /**
     * The name of the model.
     *
     * @returns The name
     */
    get name(): string;
    /**
     * The content type of the file.
     *
     * @returns The content type
     */
    get contentType(): Contents.ContentType;
    /**
     * The format of the file.
     *
     * @returns the file format
     */
    get fileFormat(): Contents.FileFormat;
    /**
     * Get whether the model factory has been disposed.
     *
     * @returns disposed status
     */
    get isDisposed(): boolean;
    /**
     * Dispose the model factory.
     */
    dispose(): void;
    /**
     * Get the preferred language given the path on the file.
     *
     * @param path path of the file represented by this document model
     * @returns The preferred language
     */
    preferredLanguage(path: string): string;
    /**
     * Create a new instance of CollaborativeChatModel.
     *
     * @param languagePreference Language
     * @param modelDB Model database
     * @returns The model
     */
    createNew(options: DocumentRegistry.IModelOptions<YChat>): CollaborativeChatModel;
    private _disposed;
    private _user;
    private _widgetConfig;
}
