import { ChatModel, IChatMessage, INewMessage, IUser } from '@jupyter/chat';
import { IChangedArgs } from '@jupyterlab/coreutils';
import { DocumentRegistry } from '@jupyterlab/docregistry';
import { User } from '@jupyterlab/services';
import { PartialJSONObject } from '@lumino/coreutils';
import { ISignal } from '@lumino/signaling';
import { IWidgetConfig } from './token';
import { YChat } from './ychat';
/**
 * Collaborative chat namespace.
 */
export declare namespace CollaborativeChatModel {
    interface IOptions extends ChatModel.IOptions {
        widgetConfig: IWidgetConfig;
        user: User.IIdentity | null;
        sharedModel?: YChat;
        languagePreference?: string;
    }
}
/**
 * The collaborative chat model.
 */
export declare class CollaborativeChatModel extends ChatModel implements DocumentRegistry.IModel {
    constructor(options: CollaborativeChatModel.IOptions);
    readonly collaborative = true;
    get user(): IUser;
    get sharedModel(): YChat;
    get contentChanged(): ISignal<this, void>;
    get stateChanged(): ISignal<this, IChangedArgs<any, any, string>>;
    get dirty(): boolean;
    set dirty(value: boolean);
    get readOnly(): boolean;
    set readOnly(value: boolean);
    get disposed(): ISignal<CollaborativeChatModel, void>;
    dispose(): void;
    toString(): string;
    fromString(data: string): void;
    toJSON(): PartialJSONObject;
    fromJSON(data: PartialJSONObject): void;
    addMessage(message: INewMessage): Promise<boolean | void> | boolean | void;
    updateMessage(id: string, updatedMessage: IChatMessage): Promise<boolean | void> | boolean | void;
    deleteMessage(id: string): Promise<boolean | void> | boolean | void;
    private _onchange;
    readonly defaultKernelName: string;
    readonly defaultKernelLanguage: string;
    private _sharedModel;
    private _dirty;
    private _readOnly;
    private _disposed;
    private _contentChanged;
    private _stateChanged;
    private _user;
}
