import { IConfig } from '@jupyter/chat';
import { Token } from '@lumino/coreutils';
import { ISignal } from '@lumino/signaling';
import { DocumentRegistry } from '@jupyterlab/docregistry';
import { ChatPanel } from './widget';
/**
 * The file type for a chat document.
 */
export declare const chatFileType: DocumentRegistry.IFileType;
/**
 * The token for the chat widget config
 */
export declare const IWidgetConfig: Token<IWidgetConfig>;
/**
 * Chat widget config
 */
export interface IWidgetConfig {
    /**
     * The widget config
     */
    config: Partial<IConfig>;
    /**
     * A signal emitting when the configuration for the chats has changed.
     */
    configChanged: IConfigChanged;
}
/**
 * A signal emitting when the configuration for the chats has changed.
 */
export interface IConfigChanged extends ISignal<IWidgetConfig, Partial<IConfig>> {
}
/**
 * Command ids.
 */
export declare const CommandIDs: {
    /**
     * Create a chat file.
     */
    createChat: string;
    /**
     * Open a chat file.
     */
    openChat: string;
    /**
     * Move a main widget to the side panel
     */
    moveToSide: string;
};
/**
 * The chat panel token.
 */
export declare const IChatPanel: Token<ChatPanel>;
