import { ChatWidget, IChatModel, IConfig } from '@jupyter/chat';
import { ICollaborativeDrive } from '@jupyter/docprovider';
import { IThemeManager } from '@jupyterlab/apputils';
import { DocumentWidget } from '@jupyterlab/docregistry';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { SidePanel } from '@jupyterlab/ui-components';
import { CommandRegistry } from '@lumino/commands';
import { Message } from '@lumino/messaging';
import { Panel } from '@lumino/widgets';
import { CollaborativeChatModel } from './model';
/**
 * DocumentWidget: widget that represents the view or editor for a file type.
 */
export declare class CollaborativeChatWidget extends DocumentWidget<ChatWidget, CollaborativeChatModel> {
    constructor(options: DocumentWidget.IOptions<ChatWidget, CollaborativeChatModel>);
    /**
     * Dispose of the resources held by the widget.
     */
    dispose(): void;
    /**
     * The model for the widget.
     */
    get model(): CollaborativeChatModel | null;
}
/**
 * Sidepanel widget including the chats and the add chat button.
 */
export declare class ChatPanel extends SidePanel {
    /**
     * The constructor of the chat panel.
     */
    constructor(options: ChatPanel.IOptions);
    /**
     * Getter and setter of the config, propagated to all the chat widgets.
     */
    get config(): IConfig;
    set config(value: Partial<IConfig>);
    /**
     * Add a new widget to the chat panel.
     *
     * @param model - the model of the chat widget
     * @param name - the name of the chat.
     */
    addChat(model: IChatModel, name: string): void;
    updateChatNames: () => Promise<void>;
    /**
     * A message handler invoked on an `'after-show'` message.
     */
    protected onAfterShow(msg: Message): void;
    /**
     * Handle `change` events for the HTMLSelect component.
     */
    private _chatSelected;
    /**
     * Triggered when a section is toogled. If the section is opened, all others
     * sections are closed.
     */
    private _onExpansionToggled;
    private _chatNamesChanged;
    private _commands;
    private _config;
    private _drive;
    private _openChat;
    private _rmRegistry;
    private _themeManager;
}
/**
 * The chat panel namespace.
 */
export declare namespace ChatPanel {
    /**
     * Options of the constructor of the chat panel.
     */
    interface IOptions extends SidePanel.IOptions {
        commands: CommandRegistry;
        drive: ICollaborativeDrive;
        rmRegistry: IRenderMimeRegistry;
        themeManager: IThemeManager | null;
    }
}
/**
 * The chat section namespace.
 */
export declare namespace ChatSection {
    /**
     * Options to build a chat section.
     */
    interface IOptions extends Panel.IOptions {
        commands: CommandRegistry;
        name: string;
        widget: ChatWidget;
    }
}
