import { IChatMessage, IUser } from '@jupyter/chat';
import { Delta, DocumentChange, IMapChange, YDocument } from '@jupyter/ydoc';
import { JSONObject } from '@lumino/coreutils';
/**
 * Definition of the shared Chat changes.
 */
export type ChatChange = DocumentChange & {
    /**
     * Changes in messages.
     */
    messageChanges?: MessageChange;
    /**
     * Changes in users.
     */
    userChanges?: UserChange[];
};
/**
 * The message change type.
 */
export type MessageChange = Delta<IYmessage[]>;
/**
 * The user change type.
 */
export type UserChange = IMapChange<IUser>;
/**
 * The interface for a YMessage.
 */
export interface IYmessage extends IChatMessage {
    /**
     * The username of the message sender.
     */
    sender: string;
}
/**
 * The collaborative chat shared document.
 */
export declare class YChat extends YDocument<ChatChange> {
    /**
     * Create a new collaborative chat model.
     */
    constructor(options?: YDocument.IOptions);
    /**
     * Document version
     */
    readonly version: string;
    /**
     * Static method to create instances on the sharedModel
     *
     * @returns The sharedModel instance
     */
    static create(options?: YDocument.IOptions): YChat;
    get users(): JSONObject;
    get messages(): string[];
    getUser(username: string | undefined): IUser | undefined;
    setUser(value: IUser): void;
    getMessage(index: number): IYmessage | undefined;
    addMessage(value: IYmessage): void;
    updateMessage(index: number, value: IYmessage): void;
    getMessageIndex(id: string): number;
    deleteMessage(index: number): void;
    private _usersObserver;
    private _messagesObserver;
    private _users;
    private _messages;
}
